#!/bin/bash
#================
# FILE          : config.sh
#----------------
# PROJECT       : OpenSuSE KIWI Image System
# COPYRIGHT     : (c) 2006,2007,2008 SUSE LINUX Products GmbH. All rights reserved
#               :
# AUTHOR        : Marcus Schaefer <ms@suse.de>, Stephan Kulow <coolo@suse.de>
#               :
# LICENSE       : BSD
#======================================
# Functions...
#--------------------------------------
test -f /.kconfig && . /.kconfig
test -f /.profile && . /.profile

set -e
set -x

exec | tee /var/log/config.log
exec 2>&1

pl=`rpmqpack | grep package-lists-` || true
test -z "$pl" || rpm -e $pl

#======================================
# Greeting...
#--------------------------------------
echo "Configure image: [$name]..."

if test -n "$use_special_hacks"; then
#======================================
# Load sound drivers by default
#--------------------------------------
perl -ni -e 'm,^blacklist snd-, || print;' \
	/etc/modprobe.d/50-blacklist.conf

# and unmute their mixers.
perl -pi -e 's,/sbin/alsactl -F restore,/bin/set_default_volume -f,;' \
	/etc/udev/rules.d/40-alsa.rules
fi

#--------------------------------------
# these two we want to disable for policy reasons
chkconfig sshd off
chkconfig cron off

ln -s '/etc/systemd/system/clicfs.service' '/etc/systemd/system/multi-user.target.wants/clicfs.service'
ln -s '/usr/lib/systemd/system/langset.service' '/usr/lib/systemd/system/sysinit.target.wants/langset.service'
cd /

if test -e /etc/YaST2/liveinstall.patch; then
  patch -p0 < /etc/YaST2/liveinstall.patch
fi

if test -f /etc/YaST2/firstboot.xml -a -f /var/lib/livecd/config-firstboot.patch; then
   patch -f /etc/YaST2/firstboot.xml /var/lib/livecd/config-firstboot.patch
fi

# disabled for now - if you reenable, don't forget correct_live_install
# bnc#382158
# patch -p0 < /etc/YaST2/policy.patch

for i in /rpmkeys/gpg*.asc; do 
   # the import fails if kiwi already had this key
   rpm --import $i || true
   rm $i
done
rmdir /rpmkeys

insserv

rm -rf /var/cache/zypp/raw/*

bash -x /var/lib/livecd/geturls.sh
rm /var/lib/livecd/geturls.sh

#======================================
# /etc/sudoers hack to fix #297695 
# (Installation Live CD: no need to ask for password of root)
#--------------------------------------
sed -i -e "s/ALL ALL=(ALL) ALL/ALL ALL=(ALL) NOPASSWD: ALL/" /etc/sudoers 
chmod 0440 /etc/sudoers

/usr/sbin/useradd -m -u 999 linux -c "Live-CD User" -p ""

# delete passwords
passwd -d root
passwd -d linux
# empty password is ok
pam-config -a --nullok

: > /var/log/zypper.log

mv /var/lib/livecd/*.pdf /home/linux || true
rmdir /var/lib/livecd || true

chown -R linux /home/linux

chkstat --system --set

for script in /usr/share/opensuse-kiwi/live_user_scripts/*.sh; do
  if test -f $script; then
     su - linux -c "/bin/bash $script"
  fi
done

rm -rf /var/cache/zypp/packages

# bug 544314, we only want to disable the bit in common-auth-pc
sed -i -e 's,^\(.*pam_gnome_keyring.so.*\),#\1,'  /etc/pam.d/common-auth-pc

#USB /usr/bin/correct_live_for_reboot usb
#USB /usr/bin/correct_live_install usb

echo '127.0.0.2       linux.site linux' >> /etc/hosts

ln -s /usr/lib/systemd/system/runlevel5.target /etc/systemd/system/default.target
baseUpdateSysConfig /etc/sysconfig/displaymanager DISPLAYMANAGER_AUTOLOGIN linux
baseUpdateSysConfig /etc/sysconfig/keyboard KEYTABLE us.map.gz
baseUpdateSysConfig /etc/sysconfig/keyboard YAST_KEYBOARD english-us,pc104
baseUpdateSysConfig /etc/sysconfig/clock HWCLOCK "-u"

baseUpdateSysConfig /etc/sysconfig/displaymanager DISPLAYMANAGER lightdm
baseUpdateSysConfig /etc/sysconfig/windowmanager DEFAULT_WM xfce
/usr/bin/systemctl -f enable NetworkManager.service
